@@ -35,9 +35,9 @@
 static gchar *modelines_data_dir;
 
 /* Mappings: language name -> Gedit language ID */
-static GHashTable *vim_languages;
-static GHashTable *emacs_languages;
-static GHashTable *kate_languages;
+static GHashTable *vim_languages = NULL;
+static GHashTable *emacs_languages = NULL;
+static GHashTable *kate_languages = NULL;
 
 typedef enum
 {
@@ -90,13 +90,13 @@ void
 modeline_parser_shutdown ()
 {
 	if (vim_languages != NULL)
-		g_hash_table_destroy (vim_languages);
+		g_hash_table_unref (vim_languages);
 
 	if (emacs_languages != NULL)
-		g_hash_table_destroy (emacs_languages);
+		g_hash_table_unref (emacs_languages);
 
 	if (kate_languages != NULL)
-		g_hash_table_destroy (kate_languages);
+		g_hash_table_unref (kate_languages);
 	
 	vim_languages = NULL;
 	emacs_languages = NULL;
@@ -155,7 +155,7 @@ load_language_mappings (void)
 				     fname);
 
 		vim_languages = load_language_mappings_group (mappings, "vim");
-		emacs_languages	= load_language_mappings_group (mappings, "emacs");
+		emacs_languages = load_language_mappings_group (mappings, "emacs");
 		kate_languages = load_language_mappings_group (mappings, "kate");
 	}
 	else
@@ -175,22 +175,23 @@ static gchar *
 get_language_id (const gchar *language_name, GHashTable *mapping)
 {
 	gchar *name;
-	gchar *language_id;
+	gchar *language_id = NULL;
 
 	name = g_ascii_strdown (language_name, -1);
 
-	language_id = g_hash_table_lookup (mapping, name);
+	if (mapping != NULL)
+	{
+		language_id = g_hash_table_lookup (mapping, name);
 
-	if (language_id != NULL)
-	{
-		g_free (name);
-		return g_strdup (language_id);
-	}
-	else
-	{
-		/* by default assume that the gtksourcevuew id is the same */
-		return name;
+		if (language_id != NULL)
+		{
+			g_free (name);
+			return g_strdup (language_id);
+		}
 	}
+
+	/* by default assume that the gtksourcevuew id is the same */
+	return name;
 }
 
 static gchar *
@@ -878,16 +879,9 @@ modeline_parser_apply_modeline (GtkSourceView *view)
 		                        previous,
 		                        (GDestroyNotify)free_modeline_options);
 	}
-	
+
+	g_object_unref (settings);
 	g_free (options.language_id);
 }
 
-void
-modeline_parser_deactivate (GtkSourceView *view)
-{
-	g_object_set_data (G_OBJECT (gtk_text_view_get_buffer (GTK_TEXT_VIEW (view))),
-	                   MODELINE_OPTIONS_DATA_KEY,
-	                   NULL);
-}
-
 /* vi:ts=8 */
